/******************************************************
* REQSTD  - A simple boolean requester command for use
*           within EXECUTE command files.
*******************************************************
* THIS VERSION OBSERVES "STANDARD" C PRGMG CONVENTIONS
*******************************************************
* BVO Computing Services, January 1987, Bob Riemersma
*******************************************************
* Format:   REQSTD <string>
* Template: REQSTD " "
* Purpose:  To ask the user a yes/no question from
*           within an EXECUTE command file.
* Specification:
*   REQSTD invokes a system requester displaying the
*   text argument given, and accepts either a "Yes" or
*   a"No" response via the requester's boolean gadgets.
*   This response is communicated to the command stream
*   via REQSTD's return result: 0 = No, 5 = Yes.
* Example:
*           REQSTD "Are you older than 35?"
*           IF WARN  ;WARN = Yes
*              ECHO "Hmmm, so you are."
*           ELSE
*              ECHO "Just a young whippersnapper!"
*           ENDIF
*******************************************************
* Note to rodent-haters:
*   Beginning with KS/WB 1.2 you may respond using
*   "Left Amiga-V" for "Yes", "Left Amiga-B" for "No".
******************************************************/
#include <exec/types.h>
#include <libraries/dosextens.h>
#include <intuition/intuition.h>
struct IntuitionBase *IntuitionBase;
#define INTUITION_REV 0

struct IntuiText Question =
{
   2, 1,          /* FrontPen, BackPen */
   JAM1,
   8, 6,          /* LeftEdge, TopEdge */
   NULL,          /* Use default font */
   NULL,          /* IText, filled at runtime */
   NULL           /* No linked IntuiTexts */
},
                 Positive =
{
   2, 1,
   JAM1,
   6, 4,
   NULL,
   "Yes",
   NULL
},
                 Negative =
{
   2, 1,
   JAM1,
   6, 4,
   NULL,
   "No",
   NULL
};

#define Me 0
extern struct Process *FindTask();
struct Process *Myself;

extern BOOL AutoRequest();

main(argc, argv)
   int argc;
   UBYTE *argv[];
{
   int QuestionChars,
       ReqWidth;
   BOOL Yes;

   if (argc != 2)
      exit(120);

   Question.IText = argv[1];

   /* Count # chars in argument string */
   QuestionChars = 0;
   while (*argv[1]++ != '\0')
      QuestionChars++;

   IntuitionBase = (struct IntuitionBase *)
                   OpenLibrary("intuition.library", INTUITION_REV);
   if (IntuitionBase == NULL)
      exit(FALSE);

   Myself = FindTask(Me);

   if ((ReqWidth = 8*QuestionChars+40) < 200)
      ReqWidth = 200;
   Yes = AutoRequest(Myself->pr_WindowPtr,            /* Console Window */
                     &Question, &Positive, &Negative, /* IntuiTexts */
                     NULL, NULL,                      /* No extern. events */
                     ReqWidth, 50);                   /* Width, Height */

   CloseLibrary(IntuitionBase);
   exit((Yes) ? 5 : 0);
}
